#
# spec file for package mate-notification-daemon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-notification-daemon
Version:        1.28.0
Release:        1.1
Summary:        Notification daemon for MATE
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libmatepanelapplet-4.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0)
BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-lang
Provides:       dbus(org.freedesktop.Notifications)
%glib2_gsettings_schema_requires

%description
D-Bus notification daemon for MATE.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name} \
  --disable-static                    \
  --disable-schemas-install
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file mate-notification-properties

%files
%license COPYING
%doc AUTHORS NEWS
%config %{_sysconfdir}/xdg/autostart/%{name}.desktop
%{_bindir}/mate-notification-properties
%dir %{_libexecdir}/mate-notification-daemon/
%{_libexecdir}/mate-notification-daemon/mate-notification-*
%dir %{_libdir}/mate-notification-daemon/
%dir %{_libdir}/mate-notification-daemon/engines/
%{_libdir}/mate-notification-daemon/engines/lib*.so
%{_datadir}/applications/mate-notification-properties.desktop
%{_datadir}/dbus-1/services/org.freedesktop.mate.Notifications.service
%{_datadir}/dbus-1/services/org.mate.panel.applet.MateNotificationAppletFactory.service
%dir %{_datadir}/mate-panel
%dir %{_datadir}/mate-panel/applets
%{_datadir}/mate-panel/applets/org.mate.applets.MateNotificationApplet.mate-panel-applet
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/glib-2.0/schemas/*.xml
%{_mandir}/man1/mate-notification-properties.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Tue Mar 26 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Translations update
  * Fix positioning on Wayland when output is not at position 0, 0
  * fix building with libxml 2.12.0
  * applet: Do not override the process' text domain
  * applet: Actually use translations
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * mnd-daemon: Fix memory leak.
  * daemon: Fix memory leak.
  * Add AssumedAppArmorLabel to dbus service file.
  * Update translations.
* Fri Aug 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * Update copyright to 2021
  * New panel applets
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.2:
  * Translations update
  * Use notify_stack_destroy() instead of g_clear_object()
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * build: Silent build warnings for distcheck.
  * Filter-out img elements from notification body.
  * The body of a notification may also contain hyperlinks.
  * build: Remove generated files.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.0):
  * Migrate from intltool to gettext.
  * Use gresource for mate-notification-properties.ui.
  * Use WARN_CFLAGS which are only set with
  - -enable-compiler-warnings.
  * Fix decoding the hints dictionary.
  * mate-notification-properties: Initialise do-not-disturb checkbox.
  * mate-notification-properties: Add do-not-disturb checkbox.
  * daemon.c: Check for do-not-disturb and skip notification.
  * Add do-not-disturb setting.
  * Update translations.
- Drop support for old openSUSE versions.
* Wed Jul 17 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Translations update
  * Remove trailing whitespaces
  * Change url project's website
- remove patch:
  * mate-notification-daemon-gtk-3.20.patch: we don't support
    gtk3.20 anymore
- build require gtk >= 3.22
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Migrate from dbus-glib to GDBus.
  * Use GVariant.
  * Add signals, remove annotation from xml file.
  * Fix some gdk deprecations.
  * src/daemon/daemon.c: Replace deprecated gvfs-open call by
    "gio open" from libglib2.0-bin.
  * Disable deprecation warnings for distcheck.
  * Avoid compile warning for g_type_class_add_private.
- Rebase mate-notification-daemon-gtk-3.20.patch.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Avoid deprecated gdk_screen_get_monitor_,
    gdk_screen_get_width/height(), gdk_screen_get_n_monitors()
    functions.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * Update translations.
- Add mate-notification-daemon-gtk-3.20.patch: Restore GLib 2.48
  and GTK+ 3.20 support.
* Wed Oct 25 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix high CPU usage with large timeouts.
  * Unescape URI-encoded paths for icon files.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Implement action icons support (e.g. playback control icons
    used by media players).
  * Themes: Fix some pie countdown issues.
  * Update translations.
* Tue Feb 28 2017 sor.alexei@meowr.ru
- Provide dbus(org.freedesktop.Notifications) instead of
  notificationdaemon.
* Fri Dec 30 2016 sor.alexei@meowr.ru
- Provide notificationdaemon, a virtual package by analogy with
  windowmanager.
* Fri Dec 16 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Fix markup parsing.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Build: Use 'm4' dir instead of 'macros' for m4 macros, like
    in other projects.
  * Move to GTK+3 (require GTK+ >= 3.14), drop GTK+2 code and
  - -with-gtk build option.
  * Add support for GNotification.
  * Fix escaping of special characters.
  * Fix various GTK+ deprecations.
  * Update translations.
* Sat Jul  2 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * themes: Make text translatable.
  * Save some RAM in NotifyTimeout.
  * Coco, Nodoka: Set notification window type.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Drop MateConf migration script.
  * GTK+3: Stop reversing fg/bg colours in slider theme (use
    colours from the current GTK+ theme as is).
  * Update translations.
  * Add Changelog generation.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * GTK+3: Explicitly wrap notification text at 50 characters.
  * GTK+3: Some deprecation fixes.
  * Drop MateConf migration script.
  * GTK+3: Some more fixes for the slider theme.
* Sun Jan  3 2016 sor.alexei@meowr.ru
- Switch to Gtk3.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Fix crash due to regression.
  * Gtk3 fixes.
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Multiple theme fixes.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11:
  * Fixes for Gtk3 themes.
  * Some general improvements.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Standard theme: fix crash when clicking on close button.
  * Properties: remove useless help button.
  * Fix build with GLib 2.36.
  * Some more bugfixes.
* Thu Jul 23 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Do not crash on notifications from Rhythmbox.
  * Bugfixes.
  * Update translations.
* Mon May  4 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Bugfixes
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + No changelog available
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + No changelog available
- Fix version requirements
* Thu Oct 23 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Bugfixes
  + Fix crash when active workspace us NULL
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + switch to libwnck
* Sun Jan 19 2014 p.drouand@gmail.com
- Update to version 1.7.1
  + standard: Add GTK3 support
  + slider: Add GTK3 support
  + coco: Add GTK3 support
  + nodoka: Add GTK3 support
  + update translations
* Fri Jan 17 2014 p.drouand@gmail.com
- Update to version 1.7.0
  + capplet: Add keywords in desktop file
    Closes #27 (https://github.com/mate-desktop/mate-notification-daemon/issues/27)
  + capplet: Fix typos in manpage
  +  Check value type of notification hint 'urgency' before
    dereferencing in nodoka and coco theme
  + add GTK3 support
  + configure: Support multiple wnck versions
  + let 'make dist' create tar.xz tarballs
  + update translations
  + update for automake-1.13
* Fri Oct 25 2013 p.drouand@gmail.com
- Update to version 1.6.1
  + add manpage for mate-notification-properties
  + back to libwnck
  + make automake happy: INCLUDES->AM_CPPFLAGS
  + add update-icon-cache config option for makedistcheck
  + update translations
  + fix EXTRA_DIST gsettings variable
* Sat Oct  5 2013 p.drouand@gmail.com
- Call update-desktop-database for mate-notification-properties.desktop
* Wed Apr  3 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + remove category MATE in mate-notification-properties.desktop
* Sun Mar 10 2013 nmo.marques@gmail.com
- Update to version 1.5.2
  + always show notification if 'expires never' is defined
  + use libnotify instead of libmatenotify
  + updated translations
  + minor fixes
* Thu Jan 24 2013 nmo.marques@gmail.com
- Update to version 1.5.1
  + remove unused code
  + backend now supports selecting which monitor to display
  + added 'use-active-monitor' and 'monitor-number' to schema to
    select which monitor displays notifications
  + fix engine loading portability
  + remove gettext and libtool files
  + other minor fixes
* Sun Oct 21 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + migration to gsettings and DBus
  + fix type in configure.ac and change default settings
  + fix FSF address in several files
- Add macros for glib2/gsettings and hicolor icon cache rebuild
* Sat Sep  8 2012 nmo.marques@gmail.com
- update to version 1.4.0
- copypac to X11:MATE
  + minor cosmetic fixes
* Sat Jun 16 2012 nmo.marques@gmail.com
- update to 1.3.1
  + move spec to mateconf macros and minor cleanups
- removed mate-notification-daemon-1.1.0-fix-typo-daemon.c.pach: no
  longer required
* Sun Jan  1 2012 fisiu@opensuse.org
- add mate-notification-daemon-1.1.0-fix-typo-daemon.c.pach
* Sun Jan  1 2012 fisiu@opensuse.org
- initial package from version 1.2.0
